# upstream versioning
%define kernelversion	4
%define patchlevel	9
# sublevel is now used for -stable patches
%define sublevel	56
# extstable is for extended stable patches
%define extstable	0

# kernel Makefile extraversion is substituted by
# kpatch/kgit wich are either 0 (empty), rc (kpatch), git (kgit)
%define kpatch		0

# kernel.org -gitX patch (only the number after "git")
%define kgit		0

# this is the releaseversion
%define mgarelease 	1

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-tmb :)
%define kname 		kernel-linus

%define rpmtag		%{distsuffix}%{mgaver}
%if %kpatch
%if %kgit
%define rpmrel		%mkrel 0.%{kpatch}.%{kgit}.%{mgarelease}
%else
%define rpmrel		%mkrel 0.%{kpatch}.%{mgarelease}
%endif
%else
%define rpmrel		%mkrel %{mgarelease}
%endif

# theese two never change, they are used to fool rpm/urpmi/smart
%define fakever		1
%define fakerel		%mkrel 1

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%if %sublevel
%define tar_ver   	%{kernelversion}.%{patchlevel}
%else
%define tar_ver	  	%{kernelversion}.%(expr %{patchlevel} - 1)
%endif
%else
%define tar_ver   	%{kernelversion}.%{patchlevel}
%endif
%if %extstable
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}
%else
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%endif
%define kverrel   	%{kversion}-%{rpmrel}

# used for not making too long names for rpms or search paths
%if %kpatch
%if %kgit
%define buildrpmrel     0.%{kpatch}.%{kgit}.%{mgarelease}%{rpmtag}
%else
%define buildrpmrel     0.%{kpatch}.%{mgarelease}%{rpmtag}
%endif
%else
%define buildrpmrel     %{mgarelease}%{rpmtag}
%endif

%define buildrel        %{kversion}-%{buildrpmrel}

%define klinus_notice NOTE: This kernel has no Mageia patches and no third-party drivers.

# having different top level names for packges means that you have to remove them by hard :(
%define top_dir_name    %{kname}-%{_arch}

%define build_dir       ${RPM_BUILD_DIR}/%{top_dir_name}
%define src_dir         %{build_dir}/linux-%{tar_ver}

# disable useless debug rpms...
%define _enable_debug_packages  %{nil}
%define debug_package           %{nil}

# build defines
%define build_doc 1
%define build_source 1
%define build_devel 1

%define build_kernel 1

%define distro_branch %(perl -pe '/(\\d+)\\.(\\d)\\.?(\\d)?/; $_="$1.$2"' /etc/mageia-release)

# End of user definitions
%{?_without_kernel: %global build_kernel 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}

%{?_with_kernel: %global build_kernel 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make_build CC="$CC"
%else
%define kmake %make_build
%endif
# there are places where parallel make doesn't work
%define smake make

# Parallelize xargs invocations on smp machines
%define kxargs xargs %([ -z "$RPM_BUILD_NCPUS" ] \\\
	&& RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"; \\\
	[ "$RPM_BUILD_NCPUS" -gt 1 ] && echo "-P $RPM_BUILD_NCPUS")

# Aliases for amd64 builds (better make source links?)
%define target_cpu	%(echo %{_target_cpu} | sed -e "s/amd64/x86_64/")
%define target_arch	%(echo %{_arch} | sed -e "s/amd64/x86_64/" -e 's/arm.*/arm/')

# src.rpm description
Summary: 	The Linux kernel (the core of the Linux operating system)
Name:           %{kname}
Version:        %{kversion}
Release:        %{rpmrel}
License: 	GPLv2
Group: 		System/Kernel and hardware
ExclusiveArch: 	%{ix86} x86_64 %{arm}
ExclusiveOS: 	Linux
URL: 		http://www.kernel.org/

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0:        ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.xz
Source1:        ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.sign

# This is for disabling mrproper and other targets on -devel rpms
Source2:	disable-mrproper-in-devel-rpms.patch

Source4:  	README.kernel-sources

# Kernel defconfigs
Source20: 	i386_defconfig
Source21: 	x86_64_defconfig
Source22:	arm_defconfig

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v(kernelversion).(patchlevel)/testing

%if %sublevel
Patch1:         ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.x/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.xz
Source11:       ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.x/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.sign
%endif
%if %kpatch
Patch2:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.x/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.xz
Source12:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.x/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.sign
%endif
%if %extstable
Patch3:		patch-%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}.patch
%endif

# critical fixes

#END
####################################################################

# global defines
Autoreqprov: 	no
BuildRequires: 	gcc
BuildRequires: 	kmod >= 12-2
BuildRequires: 	bc
BuildRequires: binutils >= 1:2.25.1

%description
Source package to build the Linux kernel.

%{klinus_notice}


#
# kernel: Symmetric MultiProcessing kernel
#
%if %build_kernel
%package -n %{kname}-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
%ifarch %{ix86}
Summary:	Linux Kernel for desktop use with i586 & 4GB RAM
%else
%ifarch %{arm}
Summary:	Linux Kernel for Arm machines based on Kirkwood
%else
Summary:	Linux Kernel for desktop use with %{_arch}
%endif
%endif
Group:		System/Kernel and hardware
Provides:	should-restart = system
Provides:	kernel = %{tar_ver}
Provides:	alsa
Requires:	bootloader-utils >= 1.16-1
Requires:	dracut >= 038-21
Requires:	kmod >= 12-2
Requires:	sysfsutils >= 2.1.0-16
Requires:	kernel-firmware >= 20170101-1

# conflict dkms packages that dont support kernel-4.9
Conflicts:	dkms-broadcom-wl < 6.30.223.271-45
Conflicts:	dkms-fglrx < 15.302
Conflicts:	dkms-nvidia-current < 375.39-1
Conflicts:	dkms-nvidia340 < 340.102-1
Conflicts:	dkms-nvidia304 < 304.135-1
Conflicts:	dkms-virtualbox < 5.1.10-3
Conflicts:	dkms-xtables-addons < 2.11-3
# not supported by x11-server-1.16
Conflicts:	dkms-nvidia173 <= 173.14.39
# (tmb) nvidia96xx does not support this kernel or x11-server-1.13
Conflicts:	dkms-nvidia96xx <= 96.43.23
# (tmb) conflict too old lvm2 rules to make upgrades work (tv, mga #9536)
Conflicts:	lvm2 < 2.02.98-3
# (tmb) conflict too old drakxtools-backend to avoid bogus root=/dev/ (#9536)
Conflicts:	drakxtools-backend < 15.37-1
# (tmb) conflict older btrfs-progs to get the new in same transaction and in initrd
Conflicts:	btrfs-progs < 4.9-2
# (tmb) conflict too old plymouth (mga#15486)
Conflicts:	plymouth < 0.8.6.1-13
# (tmb) conflict too old radeon-firmware to get the uvd firmwares in initrd
Conflicts:	radeon-firmware < 20170101-1
# (tmb) conflict old firmware to get the firmwares in initrd
Conflicts:	kernel-firmware-nonfree < 20170101-1
# (tmb) conflict old microcode to get updated ones in initrd for early loading
Conflicts:	microcode < 0.20170707-1
# (tmb) conflict old theme to get mga5 theme in initrd
Conflicts:	mageia-gfxboot-theme < 4.5.6.6-1
# (tmb) conflict too old grub2(-efi)
Conflicts:	grub2 < 2.02-0.git9752.18
Conflicts:	grub2-efi < 2.02-0.git9752.18
# (tmb) conflict too old efibootmgr
Conflicts:	efibootmgr < 0.11.0-7
# (tmb) conflict for vmmouse breakage (mga#16954)
Conflicts:	x11-driver-input-vmmouse < 13.1.0-1

%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-%{buildrel}
%ifarch %{ix86}
This kernel is compiled for desktop use, single or multiple i586
processor(s)/core(s) and less than 4GB RAM, using HZ_1000, voluntary
preempt, CFS cpu scheduler and cfq i/o scheduler.
This kernel relies on in-kernel smp alternatives to switch between
up & smp mode depending on detected hardware. To force the kernel
to boot in single processor mode, use the "nosmp" boot parameter.
%else
%ifarch %{arm}
This kernel is compiled for Arm Kirkwood boxes. It will run on openrd
boards. It's configured using HZ_100, preempt, CFS cpu scheduler and
cfq i/o scheduler.
This kernel relies on in-kernel smp alternatives to switch between
up & smp mode depending on detected hardware. To force the kernel
to boot in single processor mode, use the "nosmp" boot parameter.
%else
This kernel is compiled for desktop use, single or multiple %{_arch}
processor(s)/core(s), using HZ_1000, voluntary preempt, CFS cpu
scheduler and cfq i/o scheduler.
This kernel relies on in-kernel smp alternatives to switch between
up & smp mode depending on detected hardware. To force the kernel
to boot in single processor mode, use the "nosmp" boot parameter.
%endif
%endif

%{klinus_notice}
%endif # build_kernel


#
# kernel-source: kernel sources
#
%if %build_source
%package -n %{kname}-source-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
Provides:	%{kname}-source, kernel-source = %{kverrel}
Provides:	%{kname}-source-%{kernelversion}.%{patchlevel}
Requires:	glibc-devel, ncurses-devel, make, gcc, perl, diffutils
Summary:	The source code for the Linux kernel
Group:		Development/Kernel
Autoreqprov: 	no
Buildarch:	noarch

%description -n %{kname}-source-%{buildrel}
The %{kname}-source package contains the source code files for the
Linux kernel. Theese source files are only needed if you want to build
your own custom kernel that is better tuned to your particular hardware.

If you only want the files needed to build 3rdparty (nVidia, Ati, dkms-*,...)
drivers against, install the *-devel-* rpm that is matching your kernel.

%{klinus_notice}
%endif #build_source


#
# kernel-devel: stripped kernel sources
#
%if %build_devel
%package -n %{kname}-devel-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
Provides:	kernel-devel = %{kverrel}
Summary:	The %{kname} devel files for 3rdparty modules build
Group:		Development/Kernel
Autoreqprov:	no
Requires:	glibc-devel, ncurses-devel, make, gcc, perl
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-devel-%{buildrel}
This package contains the kernel-devel files that should be enough to build
3rdparty drivers against for use with the %{kname}-%{buildrel}.

If you want to build your own kernel, you need to install the full
%{kname}-source-%{buildrel} rpm.

%{klinus_notice}
%endif #build_devel


#
# kernel-doc: documentation for the Linux kernel
#
%if %build_doc
%package -n %{kname}-doc
Version:        %{kversion}
Release:        %{rpmrel}
Summary:	Various documentation bits found in the kernel source
Group:		Documentation
Buildarch:	noarch

%description -n %{kname}-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

%{klinus_notice}
%endif #build_doc


#
# kernel-latest: virtual rpm
#
%if %build_kernel
%package -n %{kname}-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-%{buildrel}
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname} installed...

%{klinus_notice}
%endif #build_kernel


#
# kernel-source-latest: virtual rpm
#
%if %build_source
%package -n %{kname}-source-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-source-%{buildrel}
Buildarch:	noarch

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...

%{klinus_notice}
%endif #build_source


#
# kernel-devel-latest: virtual rpm
#
%if %build_devel
%package -n %{kname}-devel-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-devel
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-devel-%{buildrel}
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-devel-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-devel installed...

%{klinus_notice}
%endif #build_devel


#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

pushd %src_dir

%if %sublevel
%patch1 -p1
%endif
%if %kpatch
%patch2 -p1
%endif
%if %extstable
%patch3 -p1
%endif

# critical fixes

popd

# PATCH END


#
# Setup Begin
#


# Install defconfigs...
install %{SOURCE20} %{build_dir}/linux-%{tar_ver}/arch/x86/configs/
install %{SOURCE21} %{build_dir}/linux-%{tar_ver}/arch/x86/configs/
install %{SOURCE22} %{build_dir}/linux-%{tar_ver}/arch/arm/configs/

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" linux-%{tar_ver}/Makefile


%build
# Common target directories
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _kerneldir /usr/src/%{kname}-%{buildrel}
%define _develdir /usr/src/%{kname}-devel-%{buildrel}


# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}
%define temp_source %{temp_root}%{_kerneldir}
%define temp_devel %{temp_root}%{_develdir}


# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}


# make sure we are in the directory
cd %{src_dir}

# make sure EXTRAVERSION says what we want it to say
%if %extstable
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{extstable}-%{buildrpmrel}/" Makefile
%else
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{buildrpmrel}/" Makefile
%endif

# Prepare the kernel
%smake -s mrproper
%ifarch %{ix86} x86_64
	cp arch/x86/configs/%{target_arch}_defconfig .config
%else
	cp arch/%{target_arch}/configs/%{target_arch}_defconfig .config
%endif
%smake oldconfig

# Build the kernel
%kmake -s all
# Install kernel
install -d %{temp_boot}
install -m 644 System.map %{temp_boot}/System.map-%{buildrel}
install -m 644 .config %{temp_boot}/config-%{buildrel}
%ifarch %{arm}
	cp -f arch/arm/boot/zImage %{temp_boot}/vmlinuz-%{buildrel}
	install -d %{temp_root}/usr/lib/linux-%{buildrel}/
	for d in arch/arm/boot/dts/*.dtb; do \
		install -D -m644 $d %{temp_root}/usr/lib/linux-%{buildrel}/$(basename $d); \
	done
%else
	cp -f arch/%{target_arch}/boot/bzImage %{temp_boot}/vmlinuz-%{buildrel}
%endif

# Install modules
install -d %{temp_modules}/%{buildrel}
%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=%{buildrel} modules_install

# remove /lib/firmware, we use a separate kernel-firmware
rm -rf %{temp_root}/lib/firmware

# Save devel tree
%if %build_devel
mkdir -p %{temp_devel}
for i in $(find . -name 'Makefile*'); do cp -R --parents $i %{temp_devel};done
for i in $(find . -name 'Kconfig*' -o -name 'Kbuild*' -o -name config.mk); do cp -R --parents $i %{temp_devel};done
cp -fR include %{temp_devel}
cp -fR scripts %{temp_devel}
cp -fR tools/include %{temp_devel}/tools/
%ifarch %{arm}
	cp -fR arch/%{target_arch}/tools %{temp_devel}/arch/%{target_arch}/
%endif
%ifarch %{ix86} x86_64
	cp -fR arch/x86/boot/{ctype.h,string.{c,h}} %{temp_devel}/arch/x86/boot/
	cp -fR arch/x86/kernel/asm-offsets.{c,s} %{temp_devel}/arch/x86/kernel/
	cp -fR arch/x86/kernel/asm-offsets_{32,64}.c %{temp_devel}/arch/x86/kernel/
	cp -fR arch/x86/purgatory/* %{temp_devel}/arch/x86/purgatory/
	cp -fR arch/x86/entry/syscalls/syscall* %{temp_devel}/arch/x86/entry/syscalls/
	cp -fR arch/x86/include %{temp_devel}/arch/x86/
	cp -fR arch/x86/tools %{temp_devel}/arch/x86/
%else
	cp -fR arch/%{target_arch}/kernel/asm-offsets.{c,s} %{temp_devel}/arch/%{target_arch}/kernel/
	for f in $(find arch/%{target_arch} -name include); do cp -fR --parents $f %{temp_devel}; done
%endif

# Needed for generation of kernel/bounds.s
cp -fR kernel/bounds.c %{temp_devel}/kernel/

# needed by include/generated/timeconst.h
cp -fR kernel/time/timeconst.bc %{temp_devel}/kernel/time/

# Needed for lguest
cp -fR drivers/lguest/lg.h %{temp_devel}/drivers/lguest/

cp -fR .config Module.symvers %{temp_devel}

# Needed for truecrypt build (Danny)
cp -fR drivers/md/dm.h %{temp_devel}/drivers/md/

# Needed for external dvb tree (#41418)
cp -fR drivers/media/dvb-core/*.h %{temp_devel}/drivers/media/dvb-core/
cp -fR drivers/media/dvb-frontends/lgdt330x.h %{temp_devel}/drivers/media/dvb-frontends/

# add acpica header files, needed for fglrx build
cp -fR drivers/acpi/acpica/*.h %{temp_devel}/drivers/acpi/acpica/

# Check and clean the -devel tree
pushd %{temp_devel} >/dev/null
    %smake -s prepare scripts clean
    rm -f .config.old
popd >/dev/null

# Disable mrproper and other targets
patch -p1 -d %{temp_devel} -i %{SOURCE2}

# Fix permissions
chmod -R a+rX %{temp_devel}
%endif # build_devel

#make sure we are in the directory
cd %src_dir

# kernel-source is shipped as an unprepared tree
%smake -s mrproper


###
### Install
###
%install
install -m 644 %{SOURCE4}  .

cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}
%define target_devel %{buildroot}%{_develdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source}

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in alpha arc avr32 blackfin c6x cris frv hexagon h8300 ia64 m32r mips \
	 microblaze m68k m68knommu metag mn10300 nios2 openrisc parisc powerpc ppc \
	 s390 score sh sh64 sparc tile unicore32 v850 xtensa; do
	rm -rf %{target_source}/arch/$i

%if %build_devel
	rm -rf %{target_devel}/arch/$i
%endif
done
%ifnarch %{arm}
	rm -rf %{target_source}/arch/arm*
	rm -rf %{target_source}/include/kvm/arm*
	rm -rf %{target_source}/include/soc
	rm -rf %{target_source}/tools/arch/arm*
%endif

# remove arch files based on target arch in -devel rpms
%if %build_devel
%ifnarch %{ix86} x86_64
	rm -rf %{target_devel}/arch/x86
%endif
%ifnarch %{arm}
	rm -rf %{target_devel}/arch/arm
	rm -rf %{target_devel}/arch/arm64
	rm -rf %{target_devel}/include/kvm/arm*
	rm -rf %{target_devel}/include/soc
%endif
%endif


# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.tmp_gas_check,.mailmap,.missing-syscalls.d,arch/.gitignore,.gitattributes,.get_maintainer.ignore,.cocciconfig}
rm -rf %{target_source}/.tmp_depmod/

#endif %build_source
%endif


# compressing modules
find %{target_modules} -name "*.ko" | %kxargs xz -6e


# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be

for i in %{target_modules}/*; do
  rm -f $i/build $i/source
done


# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here
pushd %{target_modules}
for i in *; do
	/sbin/depmod -ae -b %{buildroot} -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	modules=`find . -name "*.ko.xz"`
	echo $modules | %kxargs /sbin/modinfo \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd


###
### Clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be
# able to do several rpm --short-circuit -bi for testing install
# phase without repeating compilation phase
#rm -rf %{temp_root}


###
### Scripts
###

### kernel
%if %build_kernel
%preun -n %{kname}-%{buildrel}
/sbin/installkernel -R %{buildrel}
if [ -L /lib/modules/%{buildrel}/build ]; then
    rm -f /lib/modules/%{buildrel}/build
fi
if [ -L /lib/modules/%{buildrel}/source ]; then
    rm -f /lib/modules/%{buildrel}/source
fi
pushd /boot > /dev/null
if [ -L vmlinuz-linus ]; then
    if [ "$(readlink vmlinuz-linus)" = "vmlinuz-%{buildrel}" ]; then
	rm -f vmlinuz-linus
    fi
fi
if [ -L initrd-linus.img ]; then
    if [ "$(readlink initrd-linus.img)" = "initrd-%{buildrel}.img" ]; then
	rm -f initrd-linus.img
    fi
fi
popd > /dev/null
exit 0

%post -n %{kname}-%{buildrel}
/sbin/installkernel -L %{buildrel}
if [ -d /usr/src/%{kname}-devel-%{buildrel} ]; then
    ln -sf /usr/src/%{kname}-devel-%{buildrel} /lib/modules/%{buildrel}/build
    ln -sf /usr/src/%{kname}-devel-%{buildrel} /lib/modules/%{buildrel}/source
fi
pushd /boot > /dev/null
if [ -L vmlinuz-linus ]; then
    rm -f vmlinuz-linus
fi
ln -sf vmlinuz-%{buildrel} vmlinuz-linus
if [ -L initrd-linus.img ]; then
    rm -f initrd-linus.img
fi
ln -sf initrd-%{buildrel}.img initrd-linus.img
popd > /dev/null

%posttrans -n %{kname}-%{buildrel}
if [ -x /usr/sbin/dkms_autoinstaller -a -d /usr/src/%{kname}-devel-%{buildrel} ]; then
    /usr/sbin/dkms_autoinstaller start %{buildrel}
fi

%postun -n %{kname}-%{buildrel}
/sbin/kernel_remove_initrd %{buildrel}
rm -rf /lib/modules/%{buildrel} > /dev/null
%endif # build_kernel


### kernel-devel
%if %build_devel
%post -n %{kname}-devel-%{buildrel}
# place /build and /source symlinks in place.
if [ -d /lib/modules/%{buildrel} ]; then
    ln -sf /usr/src/%{kname}-devel-%{buildrel} /lib/modules/%{buildrel}/build
    ln -sf /usr/src/%{kname}-devel-%{buildrel} /lib/modules/%{buildrel}/source
fi

%preun -n %{kname}-devel-%{buildrel}
# we need to delete <modules>/{build,source} at uninstall
if [ -L /lib/modules/%{buildrel}/build ]; then
    rm -f /lib/modules/%{buildrel}/build
fi
if [ -L /lib/modules/%{buildrel}/source ]; then
    rm -f /lib/modules/%{buildrel}/source
fi
exit 0
%endif #build_devel


###
### file lists
###

# kernel
%if %build_kernel
%files -n %{kname}-%{buildrel}
%{_bootdir}/config-%{buildrel}
%{_bootdir}/vmlinuz-%{buildrel}
%{_bootdir}/System.map-%{buildrel}
%dir %{_modulesdir}/%{buildrel}/
%{_modulesdir}/%{buildrel}/kernel
%{_modulesdir}/%{buildrel}/modules.*
%doc README.kernel-sources
%ifarch %arm
%dir /usr/lib/linux-%{buildrel}
/usr/lib/linux-%{buildrel}/*.dtb
%endif
%endif # build_kernel

# kernel-source
%if %build_source
%files -n %{kname}-source-%{buildrel}
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.gitignore
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/Kbuild
%{_kerneldir}/Kconfig
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/Kconfig
%ifarch %arm
%{_kerneldir}/arch/arm
%{_kerneldir}/arch/arm64
%endif
%{_kerneldir}/arch/x86
%{_kerneldir}/arch/um
%{_kerneldir}/block
%{_kerneldir}/certs
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/firmware
%{_kerneldir}/fs
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/clocksource
%{_kerneldir}/include/crypto
%{_kerneldir}/include/drm
%{_kerneldir}/include/dt-bindings
%{_kerneldir}/include/kvm
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/memory
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/ras
%{_kerneldir}/include/scsi
%ifarch %arm
%{_kerneldir}/include/soc
%endif
%{_kerneldir}/include/sound
%{_kerneldir}/include/target
%{_kerneldir}/include/trace
%{_kerneldir}/include/uapi
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/misc
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/keys
%{_kerneldir}/include/rdma
%{_kerneldir}/include/xen
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/samples
%{_kerneldir}/scripts
%{_kerneldir}/security
%{_kerneldir}/sound
%{_kerneldir}/tools
%{_kerneldir}/usr
%{_kerneldir}/virt
%doc README.kernel-sources
%endif # build_source

# kernel-devel
%if %build_devel
%files -n %{kname}-devel-%{buildrel}
%dir %{_develdir}
%dir %{_develdir}/arch
%dir %{_develdir}/include
%{_develdir}/.config
%{_develdir}/Documentation
%{_develdir}/Kbuild
%{_develdir}/Kconfig
%{_develdir}/Makefile
%{_develdir}/Module.symvers
%{_develdir}/arch/Kconfig
%ifarch %{arm}
%{_develdir}/arch/arm
%{_develdir}/arch/arm64
%endif
%ifarch %{ix86} x86_64
%{_develdir}/arch/x86
%endif
%{_develdir}/arch/um
%{_develdir}/block
%{_develdir}/certs
%{_develdir}/crypto
%{_develdir}/drivers
%{_develdir}/firmware
%{_develdir}/fs
%{_develdir}/include/Kbuild
%{_develdir}/include/acpi
%{_develdir}/include/asm-generic
%{_develdir}/include/clocksource
%{_develdir}/include/config
%{_develdir}/include/crypto
%{_develdir}/include/drm
%{_develdir}/include/dt-bindings
%{_develdir}/include/generated
%{_develdir}/include/keys
%{_develdir}/include/kvm
%{_develdir}/include/linux
%{_develdir}/include/math-emu
%{_develdir}/include/memory
%{_develdir}/include/misc
%{_develdir}/include/net
%{_develdir}/include/pcmcia
%{_develdir}/include/ras
%{_develdir}/include/rdma
%{_develdir}/include/scsi
%ifarch %arm
%{_develdir}/include/soc
%endif
%{_develdir}/include/sound
%{_develdir}/include/target
%{_develdir}/include/trace
%{_develdir}/include/uapi
%{_develdir}/include/video
%{_develdir}/include/media
%{_develdir}/include/rxrpc
%{_develdir}/include/xen
%{_develdir}/init
%{_develdir}/ipc
%{_develdir}/kernel
%{_develdir}/lib
%{_develdir}/mm
%{_develdir}/net
%{_develdir}/samples
%{_develdir}/scripts
%{_develdir}/security
%{_develdir}/sound
%{_develdir}/tools
%{_develdir}/usr
%{_develdir}/virt
%doc README.kernel-sources
%endif # build_devel


%if %build_doc
%files -n %{kname}-doc
%doc linux-%{tar_ver}/Documentation/*
%endif # build_doc

%if %build_kernel
%files -n %{kname}-latest
%endif # build_kernel

%if %build_source
%files -n %{kname}-source-latest
%endif # build_source

%if %build_devel
%files -n %{kname}-devel-latest
%endif # build_devel


%changelog
* Thu Oct 12 2017 tmb <tmb> 4.9.56-1.mga6
+ Revision: 1171434
- update to 4.9.56
- update to 4.9.55
- update to 4.9.52
- enable CC_STACKPROTECTOR_STRONG
- enable FANOTIFY_ACCESS_PERMISSIONS (mga#21498)
- update to 4.9.50
- update to 4.9.49
- update to 4.9.43
- update to 4.9.40
- update to 4.9.39
- enable support for NFS4_1 and NFS4_2 (mga#21182)
- force new HT fixed microcode in initrd

* Thu Jun 29 2017 tmb <tmb> 4.9.35-1.mga6
+ Revision: 1108700
- update to 4.9.35

* Sat Jun 24 2017 tmb <tmb> 4.9.34-2.mga6
+ Revision: 1108296
- update to 4.9.34 final

* Tue Jun 20 2017 tmb <tmb> 4.9.34-1.mga6
+ Revision: 1107969
- update to 4.9.34

* Wed Jun 14 2017 tmb <tmb> 4.9.32-1.mga6
+ Revision: 1107676
- update to 4.9.32

* Thu May 25 2017 tmb <tmb> 4.9.30-1.mga6
+ Revision: 1104590
- update to 4.9.30

* Sat May 20 2017 tmb <tmb> 4.9.29-1.mga6
+ Revision: 1103560
- sync defconfigs with core kernel
- update to 4.9.29

* Sun May 14 2017 tmb <tmb> 4.9.28-1.mga6
+ Revision: 1101115
- update to 4.9.28

* Wed May 03 2017 tmb <tmb> 4.9.26-1.mga6
+ Revision: 1098880
- update to 4.9.26

* Fri Mar 31 2017 tmb <tmb> 4.9.20-1.mga6
+ Revision: 1095537
- sync defconfigs with core kernel
- update to 4.9.20

* Fri Mar 24 2017 tmb <tmb> 4.9.17-1.mga6
+ Revision: 1094722
- update to 4.9.17

* Sat Mar 18 2017 tmb <tmb> 4.9.16-1.mga6
+ Revision: 1093436
- update to 4.9.16

* Wed Mar 15 2017 tmb <tmb> 4.9.15-1.mga6
+ Revision: 1092798
- update to 4.9.15

* Mon Feb 27 2017 tmb <tmb> 4.9.13-1.mga6
+ Revision: 1088092
- update to 4.9.13

* Fri Feb 24 2017 tmb <tmb> 4.9.12-1.mga6
+ Revision: 1087601
- dccp: fix freeing skb too early for IPV6_RECVPKTINFO (CVE-2017-6074)
- update dkms-nvidia* conflicts
- update to 4.9.12

* Sat Feb 18 2017 tmb <tmb> 4.9.11-1.mga6
+ Revision: 1086696
- update to 4.9.11

* Wed Feb 15 2017 tmb <tmb> 4.9.10-1.mga6
+ Revision: 1086353
- update to 4.9.10

* Sat Feb 04 2017 tmb <tmb> 4.9.8-1.mga6
+ Revision: 1084757
- update to 4.9.8

* Sat Jan 21 2017 tmb <tmb> 4.9.5-1.mga6
+ Revision: 1082557
- update to 4.9.5

* Sun Jan 15 2017 tmb <tmb> 4.9.4-1.mga6
+ Revision: 1081792
- update to 4.9.4

* Thu Jan 12 2017 tmb <tmb> 4.9.3-1.mga6
+ Revision: 1081206
- update to 4.9.3

* Tue Jan 10 2017 tmb <tmb> 4.9.2-1.mga6
+ Revision: 1080847
- update to 4.9.2

* Fri Jan 06 2017 tmb <tmb> 4.9.1-1.mga6
+ Revision: 1080339
- update to 4.9.1

* Wed Jan 04 2017 tmb <tmb> 4.9.0-3.mga6
+ Revision: 1080147
- sync defconfigs with core kernel
- update conflicts on dkms and firmware packages
- update conflicts on nvidia340 and nvidia304

* Mon Dec 12 2016 tmb <tmb> 4.9.0-1.mga6
+ Revision: 1074305
- update dkms conflicts
- update defconfigs
- update mrproper patch
- update to 4.9

* Sat Dec 10 2016 tmb <tmb> 4.8.14-1.mga6
+ Revision: 1074158
- update to 4.8.14
- sync defconfigs with core kernel

* Sat Dec 03 2016 tmb <tmb> 4.8.12-1.mga6
+ Revision: 1071893
- update to 4.8.12

* Sat Nov 26 2016 tmb <tmb> 4.8.11-1.mga6
+ Revision: 1070298
- fix source filelist to match arm related changes
- update to 4.8.11

  + pterjan <pterjan>
    - Fix build on arm
    - Drop BuildRequires and fix defconfig path on arm

* Mon Nov 21 2016 tmb <tmb> 4.8.10-1.mga6
+ Revision: 1068537
- update to 4.8.10
- sync defconfigs with core kernel

* Thu Oct 20 2016 tmb <tmb> 4.8.3-1.mga6
+ Revision: 1062789
- update to 4.8.3
- update conflicts on dkms-nvidia-current

* Fri Oct 07 2016 tmb <tmb> 4.8.1-1.mga6
+ Revision: 1059493
- update conflicts on dkms packages
- rebase mrproper patch
- update filelists
- update defconfigs
- update to 4.8.1

* Thu Sep 08 2016 shlomif <shlomif> 4.7.3-1.mga6
+ Revision: 1050783
- New version 4.7.3. (Tested locally).

* Sun Jul 24 2016 tmb <tmb> 4.7.0-1.mga6
+ Revision: 1043574
- update to 4.7
- sync defconfigs with core kernel
- update requires/conflicts on firmware and dkms packages

* Sat Jun 25 2016 tmb <tmb> 4.6.3-1.mga6
+ Revision: 1037565
- update to 4.6.3

* Fri Jun 10 2016 tmb <tmb> 4.6.2-1.mga6
+ Revision: 1020982
- update to 4.6.2
- sync defconfigs with core kernel

* Mon May 16 2016 tmb <tmb> 4.6.0-1.mga6
+ Revision: 1016022
- update to 4.6.0 final

* Mon May 09 2016 tmb <tmb> 4.6.0-0.rc7.1.mga6
+ Revision: 1011191
- update to 4.6-rc7

* Mon May 02 2016 tmb <tmb> 4.6.0-0.rc6.1.mga6
+ Revision: 1008635
- update to 4.6-rc6

* Mon Apr 25 2016 tmb <tmb> 4.6.0-0.rc5.1.mga6
+ Revision: 1006068
- update to 4.6-rc5
- sync arm defconfig with core kernel

* Wed Apr 20 2016 tmb <tmb> 4.6.0-0.rc4.1.mga6
+ Revision: 1003729
- update to 4.6-rc4

* Mon Apr 11 2016 tmb <tmb> 4.6.0-0.rc3.1.mga6
+ Revision: 1000196
- update to 4.6-rc3

* Sat Apr 09 2016 tmb <tmb> 4.6.0-0.rc2.1.mga6
+ Revision: 999942
- update to 4.6-rc2

* Sat Apr 09 2016 tmb <tmb> 4.4.6-1.mga6
+ Revision: 999913
- update to 4.4.6
- update requires and conflicts on firmwares and dkms packages for 4.4+ series kernels

  + pterjan <pterjan>
    - Fix arm summary

* Wed Feb 17 2016 tmb <tmb> 4.4.2-1.mga6
+ Revision: 964430
- update to 4.4.2

* Mon Feb 01 2016 tmb <tmb> 4.4.1-1.mga6
+ Revision: 930109
- update to 4.4.1

* Mon Jan 11 2016 tmb <tmb> 4.4.0-1.mga6
+ Revision: 921505
- update to 4.4 final

* Mon Jan 04 2016 tmb <tmb> 4.4.0-0.rc8.1.mga6
+ Revision: 919397
- make psmouse modular (mga#15660)
- update to 4.4-rc8

* Mon Dec 28 2015 tmb <tmb> 4.4.0-0.rc7.1.mga6
+ Revision: 916405
- sync defconfigs with core kernel
- update to 4.4-rc7

* Mon Dec 21 2015 tmb <tmb> 4.4.0-0.rc6.1.mga6
+ Revision: 912902
- update to 4.4-rc6
- update defconfigs

* Fri Dec 11 2015 tmb <tmb> 4.3.2-1.mga6
+ Revision: 909565
- update to 4.3.2

* Wed Dec 09 2015 tmb <tmb> 4.3.1-1.mga6
+ Revision: 909202
- update to 4.3.1

* Thu Nov 19 2015 tmb <tmb> 4.3.0-1.mga6
+ Revision: 904165
- update to 4.3
- update filelists
- update defconfigs

* Tue Nov 10 2015 tmb <tmb> 4.2.6-1.mga6
+ Revision: 901241
- update to 4.2.6

* Wed Oct 28 2015 tmb <tmb> 4.2.5-1.mga6
+ Revision: 895965
- update to 4.2.5

* Fri Oct 23 2015 tmb <tmb> 4.2.4-1.mga6
+ Revision: 894529
- update to 4.2.4
- conflict too old x11-driver-input-vmmouse (mga#16954)

* Sat Oct 03 2015 tmb <tmb> 4.2.3-1.mga6
+ Revision: 885968
- update to 4.2.3
- update dkms conflicts

* Tue Sep 29 2015 tmb <tmb> 4.2.2-1.mga6
+ Revision: 885153
- update to 4.2.2

* Mon Aug 31 2015 tmb <tmb> 4.2.0-1.mga6
+ Revision: 871575
- update to 4.2
  * update filelists
  * update defconfigs

* Sun Aug 30 2015 tmb <tmb> 4.1.6-4.mga6
+ Revision: 871354
- sync defconfigs with core kernel

* Fri Aug 21 2015 tmb <tmb> 4.1.6-3.mga6
+ Revision: 867131
- rebuild for new gcc

* Thu Aug 20 2015 tmb <tmb> 4.1.6-2.mga6
+ Revision: 866662
- rebuild with gcc 5.2.1

* Tue Aug 18 2015 tmb <tmb> 4.1.6-1.mga6
+ Revision: 865416
- update to 4.1.6

* Mon Aug 10 2015 tmb <tmb> 4.1.5-1.mga6
+ Revision: 862444
- update requires and conflicts for 4.1 series kernels
- update 4.1.5

* Tue Aug 04 2015 tmb <tmb> 4.1.4-1.mga6
+ Revision: 861110
- update firmware requires/conflicts
- update to 4.1.4

* Fri Jul 31 2015 tmb <tmb> 2.mga6-current
+ Revision: 860182
- testbuild with new binutils

* Wed Jul 22 2015 tmb <tmb> 4.1.3-1.mga6
+ Revision: 856186
- update to 4.1.3

* Fri Jul 10 2015 tmb <tmb> 4.1.2-1.mga6
+ Revision: 853183
- update to 4.1.2

* Tue Jul 07 2015 tmb <tmb> 4.1.1-1.mga6
+ Revision: 852292
- update to 4.1.1

* Mon Jun 22 2015 tmb <tmb> 4.1.0-1.mga6
+ Revision: 839259
- update -devel/source filelists
- update defconfigs
- update mrproper patch
- update to 4.1

* Fri May 22 2015 tmb <tmb> 3.19.8-2.mga5
+ Revision: 822497
- md/raid0: fix restore to sector variable in raid0_make_request

* Mon May 11 2015 tmb <tmb> 3.19.8-1.mga5
+ Revision: 821859
- update to 3.19.8

* Thu May 07 2015 tmb <tmb> 3.19.7-1.mga5
+ Revision: 821384
- update to 3.19.7

* Sat May 02 2015 tmb <tmb> 3.19.6-1.mga5
+ Revision: 821016
- update to 3.19.6

* Sun Mar 29 2015 tmb <tmb> 3.19.3-1.mga5
+ Revision: 819380
- update to 3.19.3

* Wed Mar 18 2015 tmb <tmb> 3.19.2-1.mga5
+ Revision: 818843
- sync defconfigs with core kernel
- update to 3.19.2

* Mon Feb 23 2015 tmb <tmb> 3.19.0-1.mga5
+ Revision: 816620
- update to 3.19 final

* Tue Feb 03 2015 tmb <tmb> 3.19.0-0.rc7.1.mga5
+ Revision: 813203
- update devel filelist
- dont ship nios2 files
- update defconfigs
- rediff mrproper patch
- update to 3.19-rc7

* Fri Jan 16 2015 tmb <tmb> 3.18.3-1.mga5
+ Revision: 811005
- update to 3.18.3
- sync defconfigs with core kernel

* Sun Dec 21 2014 tmb <tmb> 3.18.1-1.mga5
+ Revision: 804677
- update to 3.18.1

* Mon Dec 08 2014 tmb <tmb> 3.18.0-1.mga5
+ Revision: 802156
- update to 3.18 final

* Mon Dec 01 2014 tmb <tmb> 3.18.0-0.rc7.1.mga5
+ Revision: 800145
- update to 3.18-rc7

* Sat Nov 29 2014 tmb <tmb> 3.18.0-0.rc6.1.mga5
+ Revision: 799908
- rediff mrproper patch
- update defconfigs
- update to 3.18-rc6-git

* Fri Nov 21 2014 tmb <tmb> 3.17.4-1.mga5
+ Revision: 798136
- update to 3.17.4
- sync defconfigs with core kernel

* Sat Nov 15 2014 tmb <tmb> 3.17.3-1.mga5
+ Revision: 797349
- update to 3.17.3

* Thu Oct 30 2014 tmb <tmb> 3.17.2-1.mga5
+ Revision: 794756
- update to 3.17.2

* Wed Oct 15 2014 tmb <tmb> 3.17.1-1.mga5
+ Revision: 757112
- sync defconfigs with core kernel
- update to 3.17.1

* Mon Oct 06 2014 tmb <tmb> 3.17.0-1.mga5
+ Revision: 737088
- update to 3.17 final

* Mon Sep 29 2014 tmb <tmb> 3.17.0-0.rc7.1.mga5
+ Revision: 731528
- update to 3.17-rc7
- disable X86_SYSFB as it breaks KMS on some systems (mga#13098)

* Tue Sep 23 2014 tmb <tmb> 3.17.0-0.rc6.1.mga5
+ Revision: 720381
- update to 3.17-rc6

* Mon Sep 15 2014 tmb <tmb> 3.17.0-0.rc5.1.mga5
+ Revision: 676749
- update to 3.17-rc5

* Tue Sep 09 2014 tmb <tmb> 3.17.0-0.rc4.2.mga5
+ Revision: 674224
- rebuild with new glibc

* Mon Sep 08 2014 tmb <tmb> 3.17.0-0.rc4.1.mga5
+ Revision: 673526
- update to 3.17-rc4

* Mon Sep 01 2014 tv <tv> 3.17.0-0.rc3.1.mga5
+ Revision: 670469
- 3.17 RC3

* Wed Aug 27 2014 tmb <tmb> 3.17.0-0.rc2.1.mga5
+ Revision: 668530
- fix -devel and -source filelists

  + tv <tv>
    - new release
    - rm soc/tegra
    - fix "scripts/kconfig/menu.c:590:18: warning: jump may be used uninitialized in this function"
    - fix "depmod: ERROR: Found 6 modules in dependency cycles"
    - new release

* Tue Aug 05 2014 tv <tv> 3.16.0-1.mga5
+ Revision: 659998
- final release

* Mon Jul 28 2014 tv <tv> 3.16.0-0.rc7.1.mga5
+ Revision: 657757
- new release

* Fri Jun 27 2014 tmb <tmb> 3.15.2-1.mga5
+ Revision: 640210
- update to 3.15.2

* Tue Jun 17 2014 tmb <tmb> 3.15.1-1.mga5
+ Revision: 637746
- make Intel MEI modular so it can be blacklisted on problematic hw
- update to 3.15.1

* Mon Jun 09 2014 tmb <tmb> 3.15.0-1.mga5
+ Revision: 634860
- update dkms conflicts
- update defconfigs
- update to 3.15

* Sat May 31 2014 tmb <tmb> 3.14.5-1.mga5
+ Revision: 629795
- update to 3.14.5
- disable AUDITSYSCALL as its broken beyond repair
  (avoids CVE-2014-3917, and other upcoming CVEs)

* Tue May 13 2014 tmb <tmb> 3.14.4-1.mga5
+ Revision: 622542
- update to 3.14.4

* Tue May 06 2014 tmb <tmb> 3.14.3-1.mga5
+ Revision: 620890
- update to 3.14.3

* Sun Apr 27 2014 tmb <tmb> 3.14.2-1.mga5
+ Revision: 618351
- update to 3.14.2
- enable Intel P-state driver (mga#13080)

* Thu Apr 17 2014 tmb <tmb> 3.14.1-1.mga5
+ Revision: 615776
- update defconfigs
- update to 3.14.1

* Fri Apr 11 2014 tmb <tmb> 3.13.10-1.mga5
+ Revision: 613488
- switch transparent hugepages back to MADVISE
- update to 3.13.10

* Fri Mar 07 2014 tmb <tmb> 3.13.6-1.mga5
+ Revision: 600858
- update to 3.13.6

* Sat Feb 22 2014 tmb <tmb> 3.13.5-1.mga5
+ Revision: 595717
- update to 3.13.5

* Fri Feb 21 2014 tmb <tmb> 3.13.4-1.mga5
+ Revision: 595330
- update tp 3.13.4

* Sat Feb 15 2014 tmb <tmb> 3.13.3-1.mga5
+ Revision: 592067
- update to 3.13.3

* Sat Feb 08 2014 tmb <tmb> 3.13.2-1.mga5
+ Revision: 585674
- update defconfigs
- rediff 'disable mrproper in devel packages' patch
- update to 3.13.2

* Sat Feb 01 2014 tmb <tmb> 3.12.9-1.mga4
+ Revision: 568581
- x86, x32: Correct invalid use of user timespec in the kernel (CVE-2014-0038)
- update to 3.12.9

* Sat Jan 18 2014 tmb <tmb> 3.12.8-1.mga4
+ Revision: 566871
- update to 3.12.8
- sync defconfigs with core kernel

* Sun Jan 12 2014 tmb <tmb> 3.12.7-1.mga4
+ Revision: 566361
- update to 3.12.7

* Fri Dec 20 2013 tmb <tmb> 3.12.6-1.mga4
+ Revision: 559208
- update to 3.12.6

* Sun Dec 15 2013 tmb <tmb> 3.12.5-1.mga4
+ Revision: 556850
- update to 3.12.5

* Wed Dec 04 2013 tmb <tmb> 3.12.3-1.mga4
+ Revision: 555202
- update to 3.12.3

* Sat Nov 30 2013 tmb <tmb> 3.12.2-1.mga4
+ Revision: 554275
- update to 3.12.2

* Thu Nov 21 2013 tmb <tmb> 3.12.1-1.mga4
+ Revision: 552187
- update to 3.12.1

* Sun Nov 17 2013 tmb <tmb> 3.12.0-2.mga4
+ Revision: 551603
- sync defconfigs with core kernel

* Mon Nov 04 2013 tmb <tmb> 3.12.0-1.mga4
+ Revision: 549319
- update to 3.12 final

* Thu Oct 31 2013 tmb <tmb> 3.12.0-0.rc7.1.mga4
+ Revision: 548126
- update to 3.12-rc7

* Mon Oct 21 2013 tmb <tmb> 3.12.0-0.rc6.1.mga4
+ Revision: 540574
- update to 3.12-rc6

* Mon Oct 14 2013 tmb <tmb> 3.12.0-0.rc5.1.mga4
+ Revision: 496720
- update to 3.12-rc5
- update defconfigs
- update dkms conflicts

* Thu Oct 03 2013 tmb <tmb> 3.11.4-1.mga4
+ Revision: 490920
- update to 3.11.4

  + tv <tv>
    - disable GOLDFISH emulator support (mga #11062)

* Fri Sep 27 2013 tmb <tmb> 3.11.2-1.mga4
+ Revision: 487573
- update to 3.11.2

* Tue Sep 17 2013 tmb <tmb> 3.11.1-1.mga4
+ Revision: 480789
- update to 3.11.1

* Tue Sep 03 2013 tmb <tmb> 3.11.0-1.mga4
+ Revision: 474657
- update to 3.11 final

* Tue Aug 27 2013 tmb <tmb> 3.11.0-0.rc7.1.mga4
+ Revision: 472258
- enable checkpoint/restore (requested by blino)
- update to 3.11-rc7

* Wed Aug 21 2013 tmb <tmb> 3.11.0-0.rc6.1.mga4
+ Revision: 469152
- update to 3.11-rc6

* Mon Aug 12 2013 tmb <tmb> 3.11.0-0.rc5.1.mga4
+ Revision: 465741
- update to 3.11-rc5

* Sun Aug 11 2013 tmb <tmb> 3.11.0-0.rc4.5.mga4
+ Revision: 465393
- rebuild with new gcc

* Tue Aug 06 2013 tmb <tmb> 3.11.0-0.rc4.4.mga4
+ Revision: 464078
- gcc-4.8.2 build

* Mon Aug 05 2013 tmb <tmb> 3.11.0-0.rc4.3.mga4
+ Revision: 464077
- disable FW_LOADER_USER_HELPER as udev is not doing any fw loading anymore
- re-enable HOTPLUG_PCI support mistakenly disabled in -rc4 update

* Sun Aug 04 2013 tmb <tmb> 3.11.0-0.rc4.2.mga4
+ Revision: 463632
- gcc-4.8.2 build

* Sun Aug 04 2013 tmb <tmb> 3.11.0-0.rc4.1.mga4
+ Revision: 463631
- update to 3.11-rc4

* Thu Aug 01 2013 tmb <tmb> 3.11.0-0.rc3.5.mga4
+ Revision: 462257
- force gcc 4.8.2 build

* Thu Aug 01 2013 tmb <tmb> 3.11.0-0.rc3.2.mga4
+ Revision: 462180
- test gcc-4.8.2 build

* Mon Jul 29 2013 tmb <tmb> 3.11.0-0.rc3.1.mga4
+ Revision: 460384
- update to 3.11-rc3

* Sun Jul 21 2013 tmb <tmb> 3.11.0-0.rc2.1.mga4
+ Revision: 456901
- update to 3.11-rc2
- update conflicts on radeon-firmware

* Sat Jul 20 2013 tv <tv> 3.11.0-0.rc1.1.mga4
+ Revision: 456382
- drop KVM ARM include files
- disable MLX5_CORE
- disable USB_CHIPIDEA
- 3.11 RC1

* Sun Jul 14 2013 tmb <tmb> 3.10.1-1.mga4
+ Revision: 454153
- update to 3.10.1

* Tue Jul 09 2013 tmb <tmb> 3.10.0-1.mga4
+ Revision: 452155
- conflict too old radeon-firmware to get the new UVD firmware in initrd
- require uptodate kernel-firmware
- update filelists
- update defconfigs
- update to 3.10
- add support for extended stable builds

* Fri Jun 28 2013 tmb <tmb> 3.9.8-1.mga4
+ Revision: 447722
- update to 3.9.8

* Fri Jun 21 2013 tmb <tmb> 3.9.7-1.mga4
+ Revision: 445329
- update to 3.9.7

* Sat May 25 2013 tmb <tmb> 3.9.4-1.mga4
+ Revision: 426934
- BR: bc
- dont package arc and metag arches
- enable CONFIG_FHANDLE
- update defconfigs
- update mrproper patch
- update to 3.9.4

* Sun May 12 2013 tmb <tmb> 3.8.13-1.mga3
+ Revision: 413031
- update to 3.8.13

* Wed May 08 2013 tmb <tmb> 3.8.12-1.mga3
+ Revision: 412639
- update to 3.8.12

* Wed May 01 2013 tmb <tmb> 3.8.11-1.mga3
+ Revision: 411790
- 3.8.11

* Sat Apr 27 2013 tmb <tmb> 3.8.10-2.mga3
+ Revision: 411416
- dont make EFI_VARS builtin on i586
- dont make NLS_CODEPAGE_437 builtin

* Sat Apr 27 2013 tmb <tmb> 3.8.10-1.mga3
+ Revision: 411312
- sync defconfigs with core kernel
- update to 3.8.10
- update to 3.8.9

* Sat Apr 13 2013 tmb <tmb> 3.8.7-1.mga3
+ Revision: 409828
- sync defconfigs with core kernel
- update to 3.8.7

* Sun Apr 07 2013 tmb <tmb> 3.8.6-1.mga3
+ Revision: 408723
- update to 3.8.6

* Sat Mar 30 2013 tmb <tmb> 3.8.5-1.mga3
+ Revision: 406597
- disable efivars as a storage backend for pstore by default
  as it can brick some computers
- update to 3.8.5

* Fri Mar 15 2013 tmb <tmb> 3.8.3-1.mga3
+ Revision: 403286
- update to 3.8.3

* Thu Feb 28 2013 tmb <tmb> 3.8.1-1.mga3
+ Revision: 400682
- update to 3.8.1

* Tue Feb 19 2013 tmb <tmb> 3.8.0-1.mga3
+ Revision: 399294
- update to 3.8 final

* Fri Feb 08 2013 tmb <tmb> 3.8.0-0.rc7.1.mga3
+ Revision: 397137
- update to 3.8-rc7
- sync defconfigs with core kernel

* Tue Feb 05 2013 tmb <tmb> 3.8.0-0.rc6.1.mga3
+ Revision: 394675
- update to 3.8-rc6

* Sun Jan 27 2013 tmb <tmb> 3.8.0-0.rc5.1.mga3
+ Revision: 392576
- update to 3.8-rc5

* Fri Jan 18 2013 tmb <tmb> 3.8.0-0.rc4.1.mga3
+ Revision: 389470
- update to 3.8-rc4

* Thu Jan 10 2013 tmb <tmb> 3.8.0-0.rc3.1.mga3
+ Revision: 344622
- update to 3.8-rc3

* Sun Jan 06 2013 tmb <tmb> 3.8.0-0.rc2.1.mga3
+ Revision: 340152
- drop build, source symlinking of source package to kernel tree as
  it makes dkms build unusable modules
- update to 3.8-rc2-git as of 2013-01-04

* Mon Dec 17 2012 tmb <tmb> 3.7.1-1.mga3
+ Revision: 332152
- update to 3.7.1

* Tue Dec 11 2012 tmb <tmb> 3.7.0-1.mga3
+ Revision: 329569
- update to 3.7 final

* Mon Dec 03 2012 tmb <tmb> 3.7.0-0.rc8.1.mga3
+ Revision: 326174
- update to 3.7-rc8

* Tue Nov 27 2012 tmb <tmb> 3.7.0-0.rc7.1.mga3
+ Revision: 322346
- update to 3.7-rc7

* Sat Nov 17 2012 tmb <tmb> 3.7.0-0.rc6.1.mga3
+ Revision: 319160
- update filelists
- rediff mrproper patch
- update defconfigs
- update to 3.7-rc6

* Sat Nov 10 2012 tmb <tmb> 3.6.6-1.mga3
+ Revision: 316860
- update to 3.6.6

* Wed Oct 31 2012 tmb <tmb> 3.6.5-1.mga3
+ Revision: 311789
- update to 3.6.5

* Sun Oct 28 2012 tmb <tmb> 3.6.4-1.mga3
+ Revision: 311077
- update to 3.6.4

* Sun Oct 21 2012 tmb <tmb> 3.6.3-1.mga3
+ Revision: 309016
- update to 3.6.3

* Mon Oct 15 2012 tmb <tmb> 3.6.2-1.mga3
+ Revision: 305654
- update defconfigs
- move -doc to Documentation group
- update -devel and -source filelists
- update to 3.6.2

* Sat Sep 15 2012 tmb <tmb> 3.5.4-1.mga3
+ Revision: 294078
- update to 3.5.4

* Sun Aug 26 2012 tmb <tmb> 3.5.3-1.mga3
+ Revision: 284231
- update to 3.5.3

* Thu Aug 16 2012 tmb <tmb> 3.5.2-1.mga3
+ Revision: 281573
- update to 3.5.2

* Sat Aug 11 2012 tmb <tmb> 3.5.1-1.mga3
+ Revision: 280479
- sync defconfigs with core kernel
- update to 3.5.1

* Fri Jul 27 2012 tmb <tmb> 3.5.0-1.mga3
+ Revision: 274708
- add include/memory/ to -devel and -source filelists
- rediff mrproper patch
- update defconfigs
- update to 3.5

* Fri Jul 20 2012 tmb <tmb> 3.4.6-1.mga3
+ Revision: 272864
- update to 3.4.6
- update to 3.4.5
- enable EFI_STUB support (#6598)

* Wed Jun 27 2012 tmb <tmb> 3.4.4-2.mga3
+ Revision: 264262
- rebuild with gcc-4.7.1

* Fri Jun 22 2012 tmb <tmb> 3.4.4-1.mga3
+ Revision: 262691
- update to 3.4.4

* Tue Jun 19 2012 tmb <tmb> 3.4.3-1.mga3
+ Revision: 261975
- update to 3.4.3

* Sat Jun 09 2012 tmb <tmb> 3.4.2-1.mga3
+ Revision: 258966
- update to 3.4.2
- BR kmod instead of module-init-tools
- require kmod instead of module-init-tools

* Mon Jun 04 2012 tmb <tmb> 3.4.1-1.mga3
+ Revision: 254431
- update to 3.4.1

* Sun May 27 2012 tmb <tmb> 3.4.0-1.mga3
+ Revision: 247558
- update to 3.4.0
- update defconfigs
- update filelists

* Sat May 12 2012 tmb <tmb> 3.3.6-1.mga2
+ Revision: 235494
- update to 3.3.6

* Thu May 10 2012 tmb <tmb> 3.3.5-1.mga2
+ Revision: 235054
- update to 3.3.5

* Sat Apr 28 2012 tmb <tmb> 3.3.4-1.mga2
+ Revision: 233737
- update to 3.3.4
- require dracut >= 017-9

* Mon Apr 23 2012 tmb <tmb> 3.3.3-1.mga2
+ Revision: 232849
- update to 3.3.3

* Mon Apr 02 2012 tmb <tmb> 3.3.1-1.mga2
+ Revision: 227955
- update to 3.3.1

* Mon Mar 19 2012 tmb <tmb> 3.3.0-1.mga2
+ Revision: 224340
- update to 3.3 final

* Sun Mar 11 2012 tmb <tmb> 3.3.0-0.rc7.1.mga2
+ Revision: 222582
- sync defconfigs with core kernel
- update to 3.3-rc7

* Sun Mar 04 2012 tmb <tmb> 3.3.0-0.rc6.1.mga2
+ Revision: 218106
- update filelists
- rediff mrproper disabling patch
- update defconfigs
- update to 3.3-rc6

* Thu Mar 01 2012 tmb <tmb> 3.2.9-1.mga2
+ Revision: 216376
- update to 3.2.9

* Tue Feb 21 2012 tmb <tmb> 3.2.7-1.mga2
+ Revision: 211504
- update to 3.2.7

* Thu Feb 16 2012 tmb <tmb> 3.2.6-1.mga2
+ Revision: 209761
- compress modules with xz
- require dracut >= 016-1 for xz compressed modules support and other fixes
- update to 3.2.6

* Mon Feb 06 2012 tmb <tmb> 3.2.5-1.mga2
+ Revision: 205539
- update to 3.2.5 (including: PCI: Rework ASPM disable code)
- revert to 3.2.2 for bs test
- update to 3.2.3-rc1

* Thu Jan 26 2012 tmb <tmb> 3.2.2-2.mga2
+ Revision: 201863
- correct requires: module-init-tools >= 3.16-14 for xz support
- require module-init-tools >= 3.6-14 for xz support
- require dracut instead of mkinitrd
- sync defconfigs with core kernel

* Thu Jan 26 2012 tmb <tmb> 3.2.2-1.mga2
+ Revision: 201801
- update to 3.2.2 (CVE-2012-0056)

* Sat Jan 14 2012 tmb <tmb> 3.2.1-1.mga2
+ Revision: 195980
- update to 3.2.1

* Thu Jan 05 2012 tmb <tmb> 3.2.0-1.mga2
+ Revision: 191518
- update to 3.2 final
- require newest kernel-firmware

* Sat Dec 24 2011 tmb <tmb> 3.2.0-0.rc7.1.mga2
+ Revision: 187187
- drop buildroot and defattr
- trigger dkms build in posttrans so modules get built at kernel install
  instead of at boot (speeds up boot time with new kernel)
- update to 3.2-rc7
- fix filelists

* Thu Dec 22 2011 tmb <tmb> 3.1.6-1.mga2
+ Revision: 185704
- update to 3.1.6
- switch transparent hugepages from on by default to madvise (only enabled
  for apps that requests it), as it fixes desktop freeze when accessing
  slow media such as usb (thanks to fbui/mdv mail on @cooker ml).

* Fri Dec 09 2011 tmb <tmb> 3.1.5-1.mga2
+ Revision: 179768
- update to 3.1.5

* Tue Dec 06 2011 tmb <tmb> 3.1.4-2.mga2
+ Revision: 177125
- rebuild with gcc-4.6.2

* Tue Nov 29 2011 tmb <tmb> 3.1.4-1.mga2
+ Revision: 174078
- update to 3.1.4
  * reverts usb patch that broke isochronous devices
    (i.e. webcam, audio, or other streaming devices)

* Sun Nov 27 2011 tmb <tmb> 3.1.3-1.mga2
+ Revision: 172884
- update to 3.1.3

* Tue Nov 22 2011 tmb <tmb> 3.1.2-1.mga2
+ Revision: 170851
- update to 3.1.2

* Sat Nov 12 2011 tmb <tmb> 3.1.1-1.mga2
+ Revision: 166996
- update to 3.1.1

* Mon Oct 24 2011 tmb <tmb> 3.1.0-1.mga2
+ Revision: 157680
- update to 3.1 final

* Tue Oct 18 2011 tmb <tmb> 3.1.0-0.rc10.1.mga2
+ Revision: 156035
- update to 3.1-rc10
- re-enable usblp as it is needed by both usb-pp adapters and some printers (mga #2240, #2264)
  (cups is patched to work with both usblp and libusb)

* Wed Oct 05 2011 tmb <tmb> 3.1.0-0.rc9.1.mga2
+ Revision: 151691
- update to 3.1-rc9

* Thu Sep 29 2011 tmb <tmb> 3.1.0-0.rc8.1.mga2
+ Revision: 150383
- update to 3.1-rc8

* Thu Sep 22 2011 tmb <tmb> 3.1.0-0.rc7.1.mga2
+ Revision: 146736
- update to 3.1-rc7

* Tue Sep 13 2011 tmb <tmb> 3.1.0-0.rc6.1.mga2
+ Revision: 143066
- update to 3.1-rc6
- remove openrisc arch
- update defconfigs

* Mon Aug 29 2011 tmb <tmb> 3.0.4-1.mga2
+ Revision: 136289
- update to 3.0.4
- update to 3.0.3
- update to 3.0.2-rc1
- update to 3.0.1 final
- enable RT33XX/RT35XX pci/usb support
- update to 3.0.1-rc1
- fix location of arm defconfig
- add support for building -stable -rc
- build with -s(ilent) so only warnings and errors gets logged
- drop obsolete provides/obsoletes
- convert -source rpm to noarch
- remove arm files from source/devel rpms when not building for arm
- release 3.0 final
- disable SOUND_OSS_CORE_PRECLAIM to allow osspd to work (request by Coling Guthrie)
- add Arm Kirkwood support (openrd)
- prepare for 3.0 final
- drop kstable defines as sublevel will be used for stable patches
- resync defconfigs with core kernel

* Sun Jul 17 2011 tmb <tmb> 3.0.0-0.rc7.5.1.mga2
+ Revision: 125368
- update to 3.0-rc7-git5

* Thu Jul 14 2011 tmb <tmb> 3.0.0-0.rc7.2.1.mga2
+ Revision: 124167
- update to 3.0-rc7-git2

* Tue Jul 12 2011 tmb <tmb> 3.0.0-0.rc7.1.mga2
+ Revision: 123368
- update to 3.0-rc7

* Sun Jul 10 2011 tmb <tmb> 3.0.0-0.rc6.6.1.mga2
+ Revision: 121736
- update to 3.0-rc6-git6

* Fri Jul 08 2011 tmb <tmb> 3.0.0-0.rc6.4.1.mga2
+ Revision: 120687
- update to 3.0-rc6-git4

* Fri Jul 08 2011 tmb <tmb> 3.0.0-0.rc6.1.mga2
+ Revision: 119944
- add mgaver to rpmtag
- remove unicore32 and .tmp_depmod/ files we dont need
- update defconfigs
- rediff patch disabling mrproper in devel rpms
- update to 3.0-rc6

* Tue Jun 14 2011 tmb <tmb> 2.6.38.8-1.mga2
+ Revision: 106143
- update to 2.6.38.8 (CVE-2011-1017)

* Sun May 22 2011 tmb <tmb> 2.6.38.7-1.mga1
+ Revision: 100095
- update to 2.6.38.7 (CVE-2011-1770, CVE-2011-1776, CVE-2011-1927)

* Tue May 10 2011 tmb <tmb> 2.6.38.6-1.mga1
+ Revision: 96897
- update to 2.6.38.6
- clean /lib/modules/ on uninstall

* Tue May 03 2011 tmb <tmb> 2.6.38.5-1.mga1
+ Revision: 94428
- update to 2.6.38.5

* Fri Apr 22 2011 tmb <tmb> 2.6.38.4-1.mga1
+ Revision: 89641
- update to 2.6.38.4

* Sat Apr 16 2011 tmb <tmb> 2.6.38.3-1.mga1
+ Revision: 86239
- update to 2.6.38.3
- fix generation of modules.description (thanks tv)

* Mon Mar 28 2011 tmb <tmb> 2.6.38.2-1.mga1
+ Revision: 78343
- update to 2.6.38.2 (CVE-2011-0726)

* Thu Mar 24 2011 tmb <tmb> 2.6.38.1-1.mga1
+ Revision: 76123
- update to 2.6.38.1

* Tue Mar 15 2011 tmb <tmb> 2.6.38-1.mga1
+ Revision: 71579
- update to 2.6.38 final

* Tue Mar 08 2011 tmb <tmb> 2.6.38-0.rc8.1.mga1
+ Revision: 66637
- update to 2.6.38-rc8

* Fri Mar 04 2011 tmb <tmb> 2.6.38-0.rc7.2.1.mga1
+ Revision: 64426
- update to 2.6.38-rc7-git2

* Thu Mar 03 2011 tmb <tmb> 2.6.38-0.rc7.1.mga1
+ Revision: 63311
- update filelists
- update defconfigs
- rediff S2
- update to 2.6.38-rc7

* Fri Feb 25 2011 tmb <tmb> 2.6.37.2-1.mga1
+ Revision: 59958
- update to 2.6.37.2

* Sat Feb 19 2011 tmb <tmb> 2.6.37.1-1.mga1
+ Revision: 54095
- fix filelist for -doc subpackage
- update to 2.6.37.1
- imported package kernel-linus

